# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;
BEGIN { plan tests => 1 };
use NCAR;
ok(1); # If we made it this far, we're ok.;

#########################

# Insert your test code below, the Test module is use()ed here so read
# its man page ( perldoc Test ) for help writing this test script.
unlink( 'gmeta' );

use PDL;
use NCAR::Test qw( bndary gendat drawcl );
use strict;
   
&NCAR::gopks( 6, 1 );
&NCAR::gopwk( 1, 2, 1 );
&NCAR::gacwk( 1 );

my $Y = zeroes float, 21;
#
# Fill Y array for entry EZY of AUTOGRAPH.
#
for my $I ( 1 .. 21 ) {
  set( $Y, $I-1, exp( -.1 * $I ) * cos( $I * .5 ) );
}
#
&NCAR::ezy ($Y,21,'DEMONSTRATING EZY ENTRY OF AUTOGRAPH$');

&NCAR::frame();
&NCAR::gdawk( 1 );
&NCAR::gclwk( 1 );
&NCAR::gclks();

rename 'gmeta', 'ncgm/example.ncgm';
