#ifndef PARAMETERS_H
#define PARAMETERS_H
#define NCAR_PACKAGE_AREAS         0
#define NCAR_PACKAGE_AUTOGRPH      1
#define NCAR_PACKAGE_CONPACK       2
#define NCAR_PACKAGE_DASHPACK      3
#define NCAR_PACKAGE_EZMAP         4
#define NCAR_PACKAGE_GRIDAL        5
#define NCAR_PACKAGE_ISOSRF        6
#define NCAR_PACKAGE_LABELBAR      7
#define NCAR_PACKAGE_NGMISC        8
#define NCAR_PACKAGE_PLOTCHAR      9
#define NCAR_PACKAGE_SOFTFILL     10
#define NCAR_PACKAGE_STITLE       11
#define NCAR_PACKAGE_STRMLN       12
#define NCAR_PACKAGE_TDPACK       13
#define NCAR_PACKAGE_VELVCT       14
#define NCAR_PACKAGE_WMAP         15
#endif 
