#ifndef NCAR_FUNCTIONS_H
#define NCAR_FUNCTIONS_H

extern void aredam_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void argeti_( 
   char*,
   int*,
   long 
);


extern void argetr_( 
   char*,
   float*,
   long 
);


extern void argtai_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void arinam_( 
   int*,
   int* 
);


extern void armvam_( 
   int*,
   int*,
   int* 
);


extern void arpram_( 
   int*,
   int*,
   int*,
   int* 
);


extern void arseti_( 
   char*,
   int*,
   long 
);


extern void arsetr_( 
   char*,
   float*,
   long 
);


extern void ardbpa_( 
   int*,
   int*,
   char*,
   long 
);


extern void agback_( 
    
);


extern void agbnch_( 
   char*,
   long,
   int* 
);


extern void agcurv_( 
   float*,
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern void agdshn_( 
   char*,
   long,
   int* 
);


extern void aggetc_( 
   char*,
   char*,
   long,
   long 
);


extern void aggetf_( 
   char*,
   float*,
   long 
);


extern void aggeti_( 
   char*,
   int*,
   long 
);


extern void aggetp_( 
   char*,
   float*,
   int*,
   long 
);


extern void aggetr_( 
   char*,
   float*,
   long 
);


extern void agrstr_( 
   int* 
);


extern void agsave_( 
   int* 
);


extern void agsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void agsetf_( 
   char*,
   float*,
   long 
);


extern void agseti_( 
   char*,
   int*,
   long 
);


extern void agsetp_( 
   char*,
   float*,
   int*,
   long 
);


extern void agsetr_( 
   char*,
   float*,
   long 
);


extern void agstup_( 
   float*,
   int*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void anotat_( 
   char*,
   char*,
   int*,
   int*,
   int*,
   string1D*,
   long,
   long,
   long 
);


extern void displa_( 
   int*,
   int*,
   int* 
);


extern void ezmxy_( 
   float*,
   float*,
   int*,
   int*,
   int*,
   char*,
   long 
);


extern void ezmy_( 
   float*,
   int*,
   int*,
   int*,
   char*,
   long 
);


extern void ezxy_( 
   float*,
   float*,
   int*,
   char*,
   long 
);


extern void idbvip_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float* 
);


extern void idsfft_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float* 
);


extern void ezy_( 
   float*,
   int*,
   char*,
   long 
);


extern void hlsrgb_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void hsvrgb_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void rgbhls_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void rgbhsv_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void rgbyiq_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void yiqrgb_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void cpback_( 
   float*,
   float*,
   int* 
);


extern void cpclam_( 
   float*,
   float*,
   int*,
   int* 
);


extern void cpcldr_( 
   float*,
   float*,
   int* 
);


extern void cpcica_( 
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern void cpcltr_( 
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void cpcnrc_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void cpezct_( 
   float*,
   int*,
   int* 
);


extern void cpgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void cpgeti_( 
   char*,
   int*,
   long 
);


extern void cpgetr_( 
   char*,
   float*,
   long 
);


extern void cplbam_( 
   float*,
   float*,
   int*,
   int* 
);


extern void cplbdr_( 
   float*,
   float*,
   int* 
);


extern void cppkcl_( 
   float*,
   float*,
   int* 
);


extern void cppklb_( 
   float*,
   float*,
   int* 
);


extern void cprect_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern void cprset_( 
    
);


extern void cpscae_( 
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void cpsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void cpseti_( 
   char*,
   int*,
   long 
);


extern void cpsetr_( 
   char*,
   float*,
   long 
);


extern void cpsprs_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int* 
);


extern void cpsps1_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int* 
);


extern void cpsps2_( 
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int* 
);


extern void curved_( 
   float*,
   float*,
   int* 
);


extern void dashdb_( 
   int* 
);


extern void dashdc_( 
   char*,
   int*,
   int*,
   long 
);


extern void frstd_( 
   float*,
   float* 
);


extern void lastd_( 
    
);


extern void lined_( 
   float*,
   float*,
   float*,
   float* 
);


extern void vectd_( 
   float*,
   float* 
);


extern void dpcurv_( 
   float*,
   float*,
   int* 
);


extern void dpdraw_( 
   float*,
   float*,
   int* 
);


extern void dpfrst_( 
   float*,
   float* 
);


extern void dpgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void dpgeti_( 
   char*,
   int*,
   long 
);


extern void dpgetr_( 
   char*,
   float*,
   long 
);


extern void dplast_( 
    
);


extern void dpline_( 
   float*,
   float*,
   float*,
   float* 
);


extern void dpsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void dpseti_( 
   char*,
   int*,
   long 
);


extern void dpsetr_( 
   char*,
   float*,
   long 
);


extern void dpsmth_( 
   float*,
   float*,
   int* 
);


extern void dpvect_( 
   float*,
   float* 
);


extern int mapaci_( 
   int* 
);


extern void mapbla_( 
   int* 
);


extern void mapdrw_( 
    
);


extern void mapfst_( 
   float*,
   float* 
);


extern void mapgci_( 
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float* 
);


extern void mapgrd_( 
    
);


extern void mapgtc_( 
   char*,
   char*,
   long,
   long 
);


extern void mapgtd_( 
   char*,
   double*,
   long 
);


extern void mapgti_( 
   char*,
   int*,
   long 
);


extern void mapgtl_( 
   char*,
   int*,
   long 
);


extern void mapgtr_( 
   char*,
   float*,
   long 
);


extern void mapint_( 
    
);


extern void mapiq_( 
    
);


extern void mapiqa_( 
   int*,
   int*,
   int*,
   int* 
);


extern void mapiqd_( 
    
);


extern void mapit_( 
   float*,
   float*,
   int* 
);


extern void mapita_( 
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void mapitd_( 
   float*,
   float*,
   int* 
);


extern void maplbl_( 
    
);


extern void maplmb_( 
    
);


extern void maplot_( 
    
);


extern void mappos_( 
   float*,
   float*,
   float*,
   float* 
);


extern void maproj_( 
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void maprs_( 
    
);


extern void maprst_( 
   int* 
);


extern void mapsav_( 
   int* 
);


extern void mapset_( 
   char*,
   float*,
   float*,
   float*,
   float*,
   long 
);


extern void mapstc_( 
   char*,
   char*,
   long,
   long 
);


extern void mapstd_( 
   char*,
   double*,
   long 
);


extern void mapsti_( 
   char*,
   int*,
   long 
);


extern void mapstl_( 
   char*,
   int*,
   long 
);


extern void mapstr_( 
   char*,
   float*,
   long 
);


extern void maptra_( 
   float*,
   float*,
   float*,
   float* 
);


extern void maptri_( 
   float*,
   float*,
   float*,
   float* 
);


extern void maptrn_( 
   float*,
   float*,
   float*,
   float* 
);


extern void mapvec_( 
   float*,
   float* 
);


extern void mdfnme_( 
   char*,
   long,
   int*,
   int* 
);


extern void mdgcog_( 
   double*,
   double*,
   double*,
   double*,
   double*,
   int* 
);


extern void mdgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void mdgetd_( 
   char*,
   double*,
   long 
);


extern void mdgeti_( 
   char*,
   int*,
   long 
);


extern void mdgetl_( 
   char*,
   int*,
   long 
);


extern void mdgetr_( 
   char*,
   float*,
   long 
);


extern void mdglty_( 
   int* 
);


extern int mdiaty_( 
   int* 
);


extern int mdifnb_( 
   char*,
   long 
);


extern int mdilnb_( 
   char*,
   long 
);


extern int mdiola_( 
   int*,
   int* 
);


extern int mdiosa_( 
   int*,
   int* 
);


extern int mdipai_( 
   int*,
   int* 
);


extern int mdipan_( 
   int*,
   char*,
   long 
);


extern int mdipar_( 
   int* 
);


extern int mdisci_( 
   int* 
);


extern void mdlach_( 
   double*,
   char*,
   int*,
   int*,
   long 
);


extern void mdlbln_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void mdlblt_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void mdlnam_( 
   char*,
   int*,
   int*,
   long 
);


extern void mdlndr_( 
   char*,
   int*,
   long 
);


extern void mdlnri_( 
   char*,
   long 
);


extern void mdloch_( 
   double*,
   char*,
   int*,
   int*,
   long 
);


extern void mdname_( 
   char*,
   long,
   int* 
);


extern int mdpaci_( 
   int* 
);


extern void mdpbla_( 
   int* 
);


extern void mdpdrw_( 
    
);


extern void mdpfst_( 
   double*,
   double* 
);


extern void mdpgci_( 
   double*,
   double*,
   double*,
   double*,
   int*,
   double*,
   double* 
);


extern void mdpgrd_( 
    
);


extern void mdpint_( 
    
);


extern void mdpiq_( 
    
);


extern void mdpiqa_( 
   int*,
   int*,
   int*,
   int* 
);


extern void mdpiqd_( 
    
);


extern void mdpit_( 
   double*,
   double*,
   int* 
);


extern void mdpita_( 
   double*,
   double*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void mdpitd_( 
   double*,
   double*,
   int* 
);


extern void mdplbl_( 
    
);


extern void mdplmb_( 
    
);


extern void mdplot_( 
    
);


extern void mdppos_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdproj_( 
   char*,
   double*,
   double*,
   double*,
   long 
);


extern void mdprs_( 
    
);


extern void mdprst_( 
   int* 
);


extern void mdpsav_( 
   int* 
);


extern void mdpset_( 
   char*,
   double*,
   double*,
   double*,
   double*,
   long 
);


extern void mdptra_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdptri_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdptrn_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdpvec_( 
   double*,
   double* 
);


extern void mdrgdl_( 
   int* 
);


extern void mdrggc_( 
   int*,
   int* 
);


extern void mdrgol_( 
   int*,
   float*,
   int* 
);


extern void mdrgsc_( 
   int*,
   int* 
);


extern void mdrgsf_( 
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern void mdritd_( 
   int*,
   double*,
   double*,
   double*,
   double* 
);


extern void mdrset_( 
    
);


extern double mdscal_( 
   float*,
   float*,
   float*,
   float* 
);


extern void mdsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void mdsetd_( 
   char*,
   double*,
   long 
);


extern void mdseti_( 
   char*,
   int*,
   long 
);


extern void mdsetl_( 
   char*,
   int*,
   long 
);


extern void mdsetr_( 
   char*,
   float*,
   long 
);


extern void mdutfd_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdutfs_( 
   float*,
   float*,
   float*,
   float* 
);


extern void mdutid_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mdutin_( 
   int*,
   int*,
   int*,
   double*,
   double*,
   double*,
   double*,
   double* 
);


extern void mdutis_( 
   float*,
   float*,
   float*,
   float* 
);


extern void mpfnme_( 
   char*,
   long,
   int*,
   int* 
);


extern void mpgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void mpgetd_( 
   char*,
   double*,
   long 
);


extern void mpgeti_( 
   char*,
   int*,
   long 
);


extern void mpgetl_( 
   char*,
   int*,
   long 
);


extern void mpgetr_( 
   char*,
   float*,
   long 
);


extern void mpglty_( 
   int* 
);


extern int mpiaty_( 
   int* 
);


extern int mpifnb_( 
   char*,
   long 
);


extern int mpilnb_( 
   char*,
   long 
);


extern int mpiola_( 
   int*,
   int* 
);


extern int mpiosa_( 
   int*,
   int* 
);


extern int mpipai_( 
   int*,
   int* 
);


extern int mpipan_( 
   int*,
   char*,
   long 
);


extern int mpipar_( 
   int* 
);


extern int mpisci_( 
   int* 
);


extern void mplnam_( 
   char*,
   int*,
   int*,
   long 
);


extern void mplndr_( 
   char*,
   int*,
   long 
);


extern void mplnri_( 
   char*,
   long 
);


extern void mpname_( 
   char*,
   long,
   int* 
);


extern void mprset_( 
    
);


extern void mpsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void mpsetd_( 
   char*,
   double*,
   long 
);


extern void mpseti_( 
   char*,
   int*,
   long 
);


extern void mpsetl_( 
   char*,
   int*,
   long 
);


extern void mpsetr_( 
   char*,
   float*,
   long 
);


extern void mputfd_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mputfs_( 
   float*,
   float*,
   float*,
   float* 
);


extern void mputid_( 
   double*,
   double*,
   double*,
   double* 
);


extern void mputin_( 
   int*,
   int*,
   int*,
   double*,
   double*,
   double*,
   double*,
   double* 
);


extern void mputis_( 
   float*,
   float*,
   float*,
   float* 
);


extern void supcon_( 
   float*,
   float*,
   float*,
   float* 
);


extern void supmap_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void gflas1_( 
   int* 
);


extern void gflas2_( 
    
);


extern void gflas3_( 
   int* 
);


extern void gflas4_( 
   int*,
   char*,
   long 
);


extern void gacolr_( 
   int*,
   int*,
   int*,
   int* 
);


extern void gagetc_( 
   char*,
   char*,
   long,
   long 
);


extern void gageti_( 
   char*,
   int*,
   long 
);


extern void gagetr_( 
   char*,
   float*,
   long 
);


extern void gasetc_( 
   char*,
   char*,
   long,
   long 
);


extern void gaseti_( 
   char*,
   int*,
   long 
);


extern void gasetr_( 
   char*,
   float*,
   long 
);


extern void grid_( 
   int*,
   int*,
   int*,
   int* 
);


extern void gridal_( 
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float* 
);


extern void gridl_( 
   int*,
   int*,
   int*,
   int* 
);


extern void halfax_( 
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int* 
);


extern void labmod_( 
   char*,
   char*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   long,
   long 
);


extern void perim_( 
   int*,
   int*,
   int*,
   int* 
);


extern void periml_( 
   int*,
   int*,
   int*,
   int* 
);


extern void tick4_( 
   int*,
   int*,
   int*,
   int* 
);


extern void ticks_( 
   int*,
   int* 
);


extern void histgr_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   float*,
   int* 
);


extern void hstopc_( 
   char*,
   char*,
   int*,
   int*,
   long,
   long 
);


extern void hstopi_( 
   char*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void hstopl_( 
   char*,
   long 
);


extern void hstopr_( 
   char*,
   float*,
   int*,
   long 
);


extern void ezisos_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void isgeti_( 
   char*,
   int*,
   long 
);


extern void isgetr_( 
   char*,
   float*,
   long 
);


extern void isosrf_( 
   float*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   int*,
   float*,
   float*,
   int* 
);


extern void ispltf_( 
   float*,
   float*,
   int* 
);


extern void isseti_( 
   char*,
   int*,
   long 
);


extern void issetr_( 
   char*,
   float*,
   long 
);


extern void istr32_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void pwrzi_( 
   float*,
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void trn32i_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void lbgeti_( 
   char*,
   int*,
   long 
);


extern void lbgetr_( 
   char*,
   float*,
   long 
);


extern void lblbar_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   int*,
   int*,
   string1D*,
   int*,
   int*,
   long 
);


extern void lbseti_( 
   char*,
   int*,
   long 
);


extern void lbsetr_( 
   char*,
   float*,
   long 
);


extern void ngdots_( 
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void nglogo_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void ngezlogo_( 
    
);


extern void nggcog_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void nggsog_( 
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void ngritd_( 
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern void ngsetr_( 
   char*,
   float*,
   long 
);


extern void ngsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void nggetc_( 
   char*,
   char*,
   long,
   long 
);


extern void nggetr_( 
   char*,
   float*,
   long 
);


extern void ngseti_( 
   char*,
   int*,
   long 
);


extern void nggeti_( 
   char*,
   int*,
   long 
);


extern int ngckop_( 
   int* 
);


extern void ngmftc_( 
   int* 
);


extern void ngsrat_( 
   int*,
   int*,
   float* 
);


extern void ngwsym_( 
   char*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   long 
);


extern void ngpict_( 
   int*,
   int* 
);


extern int ngpswk_( 
   char*,
   char*,
   char*,
   long,
   long,
   long 
);


extern void pcdlsc_( 
   int* 
);


extern void pcgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void pcgeti_( 
   char*,
   int*,
   long 
);


extern void pcgetr_( 
   char*,
   float*,
   long 
);


extern void pcsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void pcseti_( 
   char*,
   int*,
   long 
);


extern void pcsetr_( 
   char*,
   float*,
   long 
);


extern void pchiqu_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void plchhq_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void pcloqu_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void plchlq_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void pcmequ_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void plchmq_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void pcpnwi_( 
   char*,
   long,
   char*,
   int*,
   long 
);


extern void ppppap_( 
   float*,
   float*,
   int*,
   int* 
);


extern void sfgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void sfgeti_( 
   char*,
   int*,
   long 
);


extern void sfgetp_( 
   int* 
);


extern void sfgetr_( 
   char*,
   float*,
   long 
);


extern void sfnorm_( 
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern void sfsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void sfseti_( 
   char*,
   int*,
   long 
);


extern void sfsetp_( 
   int* 
);


extern void sfsetr_( 
   char*,
   float*,
   long 
);


extern void sfsgfa_( 
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void sfwrld_( 
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern float cfux_( 
   float* 
);


extern float cfuy_( 
   float* 
);


extern void clsgks_( 
    
);


extern void wmbarb_( 
   float*,
   float*,
   float*,
   float* 
);


extern void wmdflt_( 
    
);


extern void wmdrft_( 
   int*,
   float*,
   float* 
);


extern void wmdrrg_( 
   int*,
   float*,
   float*,
   char*,
   int*,
   float*,
   float*,
   long 
);


extern void wmgetc_( 
   char*,
   char*,
   long,
   long 
);


extern float cmfx_( 
   int* 
);


extern float cmfy_( 
   int* 
);


extern float cmux_( 
   int* 
);


extern float cmuy_( 
   int* 
);


extern float cpfx_( 
   int* 
);


extern float cpfy_( 
   int* 
);


extern float cpux_( 
   int* 
);


extern float cpuy_( 
   int* 
);


extern float cufx_( 
   float* 
);


extern float cufy_( 
   float* 
);


extern void curve_( 
   float*,
   float*,
   int* 
);


extern void frame_( 
    
);


extern void fl2int_( 
   float*,
   float*,
   int*,
   int* 
);


extern void frstpt_( 
   float*,
   float* 
);


extern void getset_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void getsi_( 
   int*,
   int* 
);


extern void getusv_( 
   char*,
   int*,
   long 
);


extern int kfmx_( 
   float* 
);


extern int kfmy_( 
   float* 
);


extern int kfpx_( 
   float* 
);


extern int kfpy_( 
   float* 
);


extern int kupx_( 
   float* 
);


extern int kupy_( 
   float* 
);


extern int kumx_( 
   float* 
);


extern int kumy_( 
   float* 
);


extern int kmpx_( 
   int* 
);


extern int kmpy_( 
   int* 
);


extern int kpmx_( 
   int* 
);


extern int kpmy_( 
   int* 
);


extern void line_( 
   float*,
   float*,
   float*,
   float* 
);


extern void opngks_( 
    
);


extern void plotif_( 
   float*,
   float*,
   int* 
);


extern void plotit_( 
   int*,
   int*,
   int* 
);


extern void point_( 
   float*,
   float* 
);


extern void points_( 
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void pwrit_( 
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void set_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void setusv_( 
   char*,
   int*,
   long 
);


extern void sflush_( 
    
);


extern void vector_( 
   float*,
   float* 
);


extern void wtstr_( 
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   long 
);


extern void ezsrfc_( 
   float*,
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void pwrzs_( 
   float*,
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void srface_( 
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float* 
);


extern void setr_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void trn32s_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void ftitle_( 
   int* 
);


extern void slgeti_( 
   char*,
   int*,
   long 
);


extern void slgetr_( 
   char*,
   float*,
   long 
);


extern void slseti_( 
   char*,
   int*,
   long 
);


extern void slsetr_( 
   char*,
   float*,
   long 
);


extern void stitle_( 
   string1D*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   long 
);


extern void stgeti_( 
   char*,
   int*,
   long 
);


extern void stgetr_( 
   char*,
   float*,
   long 
);


extern void stinit_( 
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int* 
);


extern void stseti_( 
   char*,
   int*,
   long 
);


extern void stsetr_( 
   char*,
   float*,
   long 
);


extern void ezstrm_( 
   float*,
   float*,
   float*,
   int*,
   int* 
);


extern void strset_( 
    
);


extern void strmln_( 
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void encd_( 
   float*,
   float*,
   char*,
   int*,
   int*,
   long 
);


extern void entsr_( 
   int*,
   int* 
);


extern void eprin_( 
    
);


extern void errof_( 
    
);


extern void msbsf1_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float* 
);


extern void msbsf2_( 
   float*,
   float*,
   int*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float* 
);


extern void msceez_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void mskrv1_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void mskrv2_( 
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float* 
);


extern int msntvl_( 
   int*,
   float*,
   float* 
);


extern void msshch_( 
   float*,
   float*,
   float*,
   int* 
);


extern void mssrf1_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern float mssrf2_( 
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float* 
);


extern void mstrms_( 
   float*,
   float*,
   float*,
   float* 
);


extern int nerro_( 
   int* 
);


extern void semess_( 
   char*,
   long,
   int* 
);


extern int icfell_( 
   char*,
   int*,
   long 
);


extern void q8qst4_( 
   char*,
   char*,
   char*,
   char*,
   long,
   long,
   long,
   long 
);


extern void retsr_( 
   int* 
);


extern void seter_( 
   char*,
   int*,
   int*,
   long 
);


extern int icloem_( 
   char*,
   long 
);


extern void curve3_( 
   float*,
   float*,
   float*,
   int* 
);


extern void fence3_( 
   float*,
   float*,
   float*,
   int*,
   int*,
   float* 
);


extern void frst3_( 
   float*,
   float*,
   float* 
);


extern void line3_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void perim3_( 
   int*,
   int*,
   int*,
   int*,
   int*,
   float* 
);


extern void point3_( 
   float*,
   float*,
   float* 
);


extern void pwrzt_( 
   float*,
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void set3_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdclrs_( 
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void tddtri_( 
   float*,
   int*,
   int*,
   int* 
);


extern void tdez2d_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void tdez3d_( 
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void tdgeti_( 
   char*,
   int*,
   long 
);


extern void tdgetr_( 
   char*,
   float*,
   long 
);


extern void tdgrds_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int* 
);


extern void tdgrid_( 
   float*,
   float*,
   int*,
   float*,
   float*,
   int*,
   int* 
);


extern void tdgtrs_( 
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void tdinit_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tditri_( 
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void tdlbla_( 
   int*,
   char*,
   char*,
   float*,
   float*,
   float*,
   float*,
   float*,
   long,
   long 
);


extern void tdlbls_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   char*,
   char*,
   char*,
   char*,
   char*,
   char*,
   int*,
   long,
   long,
   long,
   long,
   long,
   long 
);


extern void tdline_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdlnpa_( 
   float*,
   float*,
   float*,
   float* 
);


extern void tdmtri_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdotri_( 
   float*,
   int*,
   int*,
   float*,
   int*,
   int* 
);


extern void tdpara_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdplch_( 
   float*,
   float*,
   char*,
   float*,
   float*,
   float*,
   long 
);


extern void tdprpa_( 
   float*,
   float*,
   float*,
   float* 
);


extern void tdprpi_( 
   float*,
   float*,
   float*,
   float* 
);


extern void tdprpt_( 
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdseti_( 
   char*,
   int*,
   long 
);


extern void tdsetr_( 
   char*,
   float*,
   long 
);


extern void tdstri_( 
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int* 
);


extern void tdstrs_( 
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void tick43_( 
   int*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void vect3_( 
   float*,
   float*,
   float* 
);


extern void ezvec_( 
   float*,
   float*,
   int*,
   int* 
);


extern void vvinit_( 
   float*,
   int*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   int* 
);


extern void velvec_( 
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   float* 
);


extern void vvgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void vvgeti_( 
   char*,
   int*,
   long 
);


extern void vvgetr_( 
   char*,
   float*,
   long 
);


extern void vvrset_( 
    
);


extern void vvsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void vvseti_( 
   char*,
   int*,
   long 
);


extern void vvsetr_( 
   char*,
   float*,
   long 
);


extern void velvct_( 
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float* 
);


extern void wmgeti_( 
   char*,
   int*,
   long 
);


extern void wmgetr_( 
   char*,
   float*,
   long 
);


extern int wmgtln_( 
   char*,
   int*,
   int*,
   long 
);


extern void wmlabc_( 
   float*,
   float*,
   char*,
   char*,
   long,
   long 
);


extern void wmlabs_( 
   float*,
   float*,
   char*,
   long 
);


extern void wmlabw_( 
   float*,
   float*,
   char*,
   long 
);


extern void wmlabt_( 
   float*,
   float*,
   char*,
   int*,
   long 
);


extern void wmlgnd_( 
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void wmrgwt_( 
   int*,
   float*,
   float*,
   int*,
   int* 
);


extern void wmsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void wmseti_( 
   char*,
   int*,
   long 
);


extern void wmsetr_( 
   char*,
   float*,
   long 
);


extern void wmstnm_( 
   float*,
   float*,
   string1D*,
   long 
);


extern void ardrln_( 
   int*,
   float*,
   float*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void arscam_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void cpcldm_( 
   float*,
   float*,
   int*,
   int*,
   void* 
);


extern void mapblm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mapgrm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mapiqm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mapitm_( 
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mdpblm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mdpgrm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mdpiqm_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mdpitm_( 
   double*,
   double*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void* 
);


extern void mplndm_( 
   char*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   void*,
   long 
);


extern void stream_( 
   float*,
   float*,
   float*,
   int*,
   void*,
   float* 
);


extern void vvectr_( 
   float*,
   float*,
   float*,
   int*,
   void*,
   float* 
);


extern void wmw2nx_( 
   int*,
   float*,
   float* 
);


extern void wmw2ny_( 
   int*,
   float*,
   float* 
);


extern void cpdrpl_( 
   float*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void ngreop_( 
   int*,
   int*,
   int*,
   char*,
   int*,
   int*,
   float*,
   int*,
   int*,
   float*,
   long 
);


extern void slrset_( 
    
);


extern void slogap_( 
   float*,
   int* 
);


extern void tdttri_( 
   float*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void tdctri_( 
   float*,
   int*,
   int*,
   int*,
   float* 
);


extern void ardbda_( 
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void ezhftn_( 
   float*,
   int*,
   int* 
);


extern void hafton_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   float* 
);


extern void pwritx_( 
   float*,
   float*,
   char*,
   int*,
   int*,
   int*,
   int*,
   long 
);


extern void init3d_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int*,
   float* 
);


extern void dandr_( 
   int*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int*,
   float*,
   int*,
   int* 
);


extern void isoscr_( 
    
);


extern void conran_( 
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   float* 
);


extern void conop1_( 
   char*,
   long 
);


extern void conop4_( 
   char*,
   char*,
   int*,
   int*,
   long,
   long 
);


extern void ezcntr_( 
   float*,
   int*,
   int* 
);


extern void conrec_( 
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int* 
);


extern void gactm_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float* 
);


extern void gacwk_( 
   int* 
);


extern void gca_( 
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int*,
   int* 
);


extern void gclks_( 
    
);


extern void gclrwk_( 
   int*,
   int* 
);


extern void gclsg_( 
    
);


extern void gclwk_( 
   int* 
);


extern void gcrsg_( 
   int* 
);


extern void gcsgwk_( 
   int*,
   int* 
);


extern void gdawk_( 
   int* 
);


extern void gdsg_( 
   int* 
);


extern void gesc_( 
   int*,
   int*,
   string1D*,
   int*,
   int*,
   string1D*,
   long,
   long 
);


extern void gevtm_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float* 
);


extern void gfa_( 
   int*,
   float*,
   float* 
);


extern void gopks_( 
   int*,
   int* 
);


extern void gopwk_( 
   int*,
   int*,
   int* 
);


extern void gpl_( 
   int*,
   float*,
   float* 
);


extern void gpm_( 
   int*,
   float*,
   float* 
);


extern void gqasf_( 
   int*,
   int* 
);


extern void gqchh_( 
   int*,
   float* 
);


extern void gqchsp_( 
   int*,
   float* 
);


extern void gqchup_( 
   int*,
   float*,
   float* 
);


extern void gqchxp_( 
   int*,
   float* 
);


extern void gqclip_( 
   int*,
   int*,
   float* 
);


extern void gqcntn_( 
   int*,
   int* 
);


extern void gqcr_( 
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void gqfaci_( 
   int*,
   int* 
);


extern void gqfais_( 
   int*,
   int* 
);


extern void gqfasi_( 
   int*,
   int* 
);


extern void gqln_( 
   int*,
   int* 
);


extern void gqlwsc_( 
   int*,
   float* 
);


extern void gqmk_( 
   int*,
   int* 
);


extern void gqmksc_( 
   int*,
   float* 
);


extern void gqmntn_( 
   int*,
   int* 
);


extern void gqnt_( 
   int*,
   int*,
   float*,
   float* 
);


extern void gqops_( 
   int* 
);


extern void gqopsg_( 
   int*,
   int* 
);


extern void gqplci_( 
   int*,
   int* 
);


extern void gqpmci_( 
   int*,
   int* 
);


extern void gqsgus_( 
   int*,
   int*,
   int*,
   int* 
);


extern void gqtxal_( 
   int*,
   int*,
   int* 
);


extern void gqtxci_( 
   int*,
   int* 
);


extern void gqtxfp_( 
   int*,
   int*,
   int* 
);


extern void gqtxp_( 
   int*,
   int* 
);


extern void gqtxx_( 
   int*,
   float*,
   float*,
   char*,
   int*,
   float*,
   float*,
   float*,
   float*,
   long 
);


extern void gsasf_( 
   int* 
);


extern void gschh_( 
   float* 
);


extern void gschsp_( 
   float* 
);


extern void gschup_( 
   float*,
   float* 
);


extern void gschxp_( 
   float* 
);


extern void gsclip_( 
   int* 
);


extern void gscr_( 
   int*,
   int*,
   float*,
   float*,
   float* 
);


extern void gselnt_( 
   int* 
);


extern void gsfaci_( 
   int* 
);


extern void gsfais_( 
   int* 
);


extern void gsfasi_( 
   int* 
);


extern void gsln_( 
   int* 
);


extern void gslwsc_( 
   float* 
);


extern void gsmk_( 
   int* 
);


extern void gsmksc_( 
   float* 
);


extern void gsplci_( 
   int* 
);


extern void gspmci_( 
   int* 
);


extern void gssgt_( 
   int*,
   float* 
);


extern void gstxal_( 
   int*,
   int* 
);


extern void gstxci_( 
   int* 
);


extern void gstxfp_( 
   int*,
   int* 
);


extern void gstxp_( 
   int* 
);


extern void gsvp_( 
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern void gswn_( 
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern void gtx_( 
   float*,
   float*,
   char*,
   long 
);


extern void guwk_( 
   int*,
   int* 
);


extern void csa1s_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa1xs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa2ls_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa2lxs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa2s_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa2xs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa3ls_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa3lxs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa3s_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csa3xs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void csc2s_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void csc2sd_( 
   int*,
   double*,
   double*,
   double*,
   double*,
   double* 
);


extern void csgetd_( 
   char*,
   double*,
   long 
);


extern void csgeti_( 
   char*,
   int*,
   long 
);


extern void csgetr_( 
   char*,
   float*,
   long 
);


extern void css2c_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void css2cd_( 
   int*,
   double*,
   double*,
   double*,
   double*,
   double* 
);


extern void cssetd_( 
   char*,
   double*,
   long 
);


extern void csseti_( 
   char*,
   int*,
   long 
);


extern void cssetr_( 
   char*,
   float*,
   long 
);


extern void cssgrid_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   double*,
   int* 
);


extern void cssgridd_( 
   int*,
   double*,
   double*,
   double*,
   int*,
   int*,
   double*,
   double*,
   double*,
   int*,
   double*,
   int* 
);


extern void csstri_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   double*,
   int* 
);


extern void csstrid_( 
   int*,
   double*,
   double*,
   int*,
   int*,
   int*,
   double*,
   int* 
);


extern void csvoro_( 
   int*,
   float*,
   float*,
   int*,
   int*,
   int*,
   double*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   int* 
);


extern void csvorod_( 
   int*,
   double*,
   double*,
   int*,
   int*,
   int*,
   double*,
   int*,
   double*,
   double*,
   double*,
   int*,
   int*,
   int*,
   int* 
);


extern void curv1_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern float curv2_( 
   float*,
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern float curvd_( 
   float*,
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern float curvi_( 
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float* 
);


extern void curvp1_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern float curvp2_( 
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern float curvpi_( 
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void curvps_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void curvs_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void dsgetc_( 
   char*,
   char*,
   long,
   long 
);


extern void dsgeti_( 
   char*,
   int*,
   long 
);


extern void dsgetr_( 
   char*,
   float*,
   long 
);


extern void dsgetrd_( 
   char*,
   double*,
   long 
);


extern void dsgrid2d_( 
   int*,
   double*,
   double*,
   double*,
   int*,
   int*,
   double*,
   double*,
   double*,
   int* 
);


extern void dsgrid2s_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern void dsgrid3d_( 
   int*,
   double*,
   double*,
   double*,
   double*,
   int*,
   int*,
   int*,
   double*,
   double*,
   double*,
   double*,
   int* 
);


extern void dsgrid3s_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void dspnt2d_( 
   int*,
   double*,
   double*,
   double*,
   int*,
   double*,
   double*,
   double*,
   int* 
);


extern void dspnt2s_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern void dspnt3d_( 
   int*,
   double*,
   double*,
   double*,
   double*,
   int*,
   double*,
   double*,
   double*,
   double*,
   int* 
);


extern void dspnt3s_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void dssetc_( 
   char*,
   char*,
   long,
   long 
);


extern void dsseti_( 
   char*,
   char*,
   long,
   long 
);


extern void dssetr_( 
   char*,
   float*,
   long 
);


extern void dssetrd_( 
   char*,
   double*,
   long 
);


extern void kurv1_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void kurv2_( 
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void kurvd_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void kurvp1_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int* 
);


extern void kurvp2_( 
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void kurvpd_( 
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float* 
);


extern void natgridd_( 
   int*,
   double*,
   double*,
   double*,
   int*,
   int*,
   double*,
   double*,
   double*,
   int* 
);


extern void natgrids_( 
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern void nngetaspectd_( 
   int*,
   int*,
   double*,
   int* 
);


extern void nngetaspects_( 
   int*,
   int*,
   float*,
   int* 
);


extern void nngetc_( 
   char*,
   char*,
   long,
   long 
);


extern void nngeti_( 
   char*,
   int*,
   long 
);


extern void nngetr_( 
   char*,
   float*,
   long 
);


extern void nngetrd_( 
   char*,
   double*,
   long 
);


extern void nngetsloped_( 
   int*,
   int*,
   double*,
   int* 
);


extern void nngetslopes_( 
   int*,
   int*,
   float*,
   int* 
);


extern void nnpntd_( 
   double*,
   double*,
   double* 
);


extern void nnpntend_( 
    
);


extern void nnpntendd_( 
    
);


extern void nnpntinitd_( 
   int*,
   double*,
   double*,
   double* 
);


extern void nnpntinits_( 
   int*,
   float*,
   float*,
   float* 
);


extern void nnpnts_( 
   float*,
   float*,
   float* 
);


extern void nnsetc_( 
   char*,
   char*,
   long,
   long 
);


extern void nnseti_( 
   char*,
   int*,
   long 
);


extern void nnsetr_( 
   char*,
   float*,
   long 
);


extern void nnsetrd_( 
   char*,
   double*,
   long 
);


extern void shgetnp_( 
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int*,
   int*,
   float*,
   int*,
   int* 
);


extern void shgrid_( 
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   int*,
   int*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   int* 
);


extern void surf1_( 
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float*,
   float*,
   int* 
);


extern float surf2_( 
   float*,
   float*,
   int*,
   int*,
   float*,
   float*,
   float*,
   int*,
   float*,
   float* 
);

typedef enum{
  FUNCTION_NAME_YIQRGB,
  FUNCTION_NAME_WMW2NY,
  FUNCTION_NAME_WMW2NX,
  FUNCTION_NAME_WMSETR,
  FUNCTION_NAME_WMSETI,
  FUNCTION_NAME_WMSETC,
  FUNCTION_NAME_WMLABW,
  FUNCTION_NAME_WMLABS,
  FUNCTION_NAME_WMGETR,
  FUNCTION_NAME_WMGETI,
  FUNCTION_NAME_WMGETC,
  FUNCTION_NAME_WMDRFT,
  FUNCTION_NAME_WMDFLT,
  FUNCTION_NAME_WMBARB,
  FUNCTION_NAME_VVSETR,
  FUNCTION_NAME_VVSETI,
  FUNCTION_NAME_VVSETC,
  FUNCTION_NAME_VVRSET,
  FUNCTION_NAME_VVINIT,
  FUNCTION_NAME_VVGETR,
  FUNCTION_NAME_VVGETI,
  FUNCTION_NAME_VVGETC,
  FUNCTION_NAME_VVECTR,
  FUNCTION_NAME_VECTOR,
  FUNCTION_NAME_VECTD,
  FUNCTION_NAME_VECT3,
  FUNCTION_NAME_TRN32S,
  FUNCTION_NAME_TRN32I,
  FUNCTION_NAME_TICKS,
  FUNCTION_NAME_TICK4,
  FUNCTION_NAME_TDSETR,
  FUNCTION_NAME_TDSETI,
  FUNCTION_NAME_TDPRPI,
  FUNCTION_NAME_TDPRPA,
  FUNCTION_NAME_TDPLCH,
  FUNCTION_NAME_TDPARA,
  FUNCTION_NAME_TDLNPA,
  FUNCTION_NAME_TDLINE,
  FUNCTION_NAME_TDGETR,
  FUNCTION_NAME_TDGETI,
  FUNCTION_NAME_SUPCON,
  FUNCTION_NAME_STSETR,
  FUNCTION_NAME_STSETI,
  FUNCTION_NAME_STRSET,
  FUNCTION_NAME_STREAM,
  FUNCTION_NAME_STINIT,
  FUNCTION_NAME_STGETR,
  FUNCTION_NAME_STGETI,
  FUNCTION_NAME_SLSETR,
  FUNCTION_NAME_SLSETI,
  FUNCTION_NAME_SLRSET,
  FUNCTION_NAME_SLGETR,
  FUNCTION_NAME_SLGETI,
  FUNCTION_NAME_SFWRLD,
  FUNCTION_NAME_SFSETR,
  FUNCTION_NAME_SFSETP,
  FUNCTION_NAME_SFSETI,
  FUNCTION_NAME_SFSETC,
  FUNCTION_NAME_SFNORM,
  FUNCTION_NAME_SFLUSH,
  FUNCTION_NAME_SFGETR,
  FUNCTION_NAME_SFGETP,
  FUNCTION_NAME_SFGETI,
  FUNCTION_NAME_SFGETC,
  FUNCTION_NAME_SETUSV,
  FUNCTION_NAME_SETER,
  FUNCTION_NAME_RGBYIQ,
  FUNCTION_NAME_RGBHSV,
  FUNCTION_NAME_RGBHLS,
  FUNCTION_NAME_RETSR,
  FUNCTION_NAME_PWRZT,
  FUNCTION_NAME_PWRZS,
  FUNCTION_NAME_PWRZI,
  FUNCTION_NAME_PWRITX,
  FUNCTION_NAME_PWRIT,
  FUNCTION_NAME_POINT3,
  FUNCTION_NAME_POINT,
  FUNCTION_NAME_PLOTIT,
  FUNCTION_NAME_PLOTIF,
  FUNCTION_NAME_PLCHMQ,
  FUNCTION_NAME_PLCHLQ,
  FUNCTION_NAME_PLCHHQ,
  FUNCTION_NAME_PERIML,
  FUNCTION_NAME_PERIM,
  FUNCTION_NAME_PCSETR,
  FUNCTION_NAME_PCSETI,
  FUNCTION_NAME_PCSETC,
  FUNCTION_NAME_PCMEQU,
  FUNCTION_NAME_PCLOQU,
  FUNCTION_NAME_PCHIQU,
  FUNCTION_NAME_PCGETR,
  FUNCTION_NAME_PCGETI,
  FUNCTION_NAME_PCGETC,
  FUNCTION_NAME_PCDLSC,
  FUNCTION_NAME_OPNGKS,
  FUNCTION_NAME_NGSETR,
  FUNCTION_NAME_NGSETI,
  FUNCTION_NAME_NGSETC,
  FUNCTION_NAME_NGPICT,
  FUNCTION_NAME_NGMFTC,
  FUNCTION_NAME_NGGETR,
  FUNCTION_NAME_NGGETI,
  FUNCTION_NAME_NGGETC,
  FUNCTION_NAME_NGEZLOGO,
  FUNCTION_NAME_NGCKOP,
  FUNCTION_NAME_MPUTIS,
  FUNCTION_NAME_MPUTIN,
  FUNCTION_NAME_MPUTID,
  FUNCTION_NAME_MPUTFS,
  FUNCTION_NAME_MPUTFD,
  FUNCTION_NAME_MPSETR,
  FUNCTION_NAME_MPSETL,
  FUNCTION_NAME_MPSETI,
  FUNCTION_NAME_MPSETD,
  FUNCTION_NAME_MPSETC,
  FUNCTION_NAME_MPRSET,
  FUNCTION_NAME_MPLNRI,
  FUNCTION_NAME_MPLNDR,
  FUNCTION_NAME_MPLNAM,
  FUNCTION_NAME_MPISCI,
  FUNCTION_NAME_MPIPAR,
  FUNCTION_NAME_MPIPAN,
  FUNCTION_NAME_MPIPAI,
  FUNCTION_NAME_MPIOSA,
  FUNCTION_NAME_MPIOLA,
  FUNCTION_NAME_MPILNB,
  FUNCTION_NAME_MPIFNB,
  FUNCTION_NAME_MPIATY,
  FUNCTION_NAME_MPGLTY,
  FUNCTION_NAME_MPGETR,
  FUNCTION_NAME_MPGETL,
  FUNCTION_NAME_MPGETI,
  FUNCTION_NAME_MPGETD,
  FUNCTION_NAME_MPGETC,
  FUNCTION_NAME_MPFNME,
  FUNCTION_NAME_MDUTIS,
  FUNCTION_NAME_MDUTIN,
  FUNCTION_NAME_MDUTID,
  FUNCTION_NAME_MDUTFS,
  FUNCTION_NAME_MDUTFD,
  FUNCTION_NAME_MDSETR,
  FUNCTION_NAME_MDSETL,
  FUNCTION_NAME_MDSETI,
  FUNCTION_NAME_MDSETD,
  FUNCTION_NAME_MDSETC,
  FUNCTION_NAME_MDRSET,
  FUNCTION_NAME_MDRGSC,
  FUNCTION_NAME_MDRGGC,
  FUNCTION_NAME_MDRGDL,
  FUNCTION_NAME_MDPVEC,
  FUNCTION_NAME_MDPTRN,
  FUNCTION_NAME_MDPTRI,
  FUNCTION_NAME_MDPTRA,
  FUNCTION_NAME_MDPSAV,
  FUNCTION_NAME_MDPRST,
  FUNCTION_NAME_MDPRS,
  FUNCTION_NAME_MDPLOT,
  FUNCTION_NAME_MDPLMB,
  FUNCTION_NAME_MDPLBL,
  FUNCTION_NAME_MDPITD,
  FUNCTION_NAME_MDPIT,
  FUNCTION_NAME_MDPIQM,
  FUNCTION_NAME_MDPIQD,
  FUNCTION_NAME_MDPIQA,
  FUNCTION_NAME_MDPIQ,
  FUNCTION_NAME_MDPINT,
  FUNCTION_NAME_MDPGRM,
  FUNCTION_NAME_MDPGRD,
  FUNCTION_NAME_MDPFST,
  FUNCTION_NAME_MDPDRW,
  FUNCTION_NAME_MDPBLM,
  FUNCTION_NAME_MDPBLA,
  FUNCTION_NAME_MDPACI,
  FUNCTION_NAME_MDLOCH,
  FUNCTION_NAME_MDLNRI,
  FUNCTION_NAME_MDLNDR,
  FUNCTION_NAME_MDLNAM,
  FUNCTION_NAME_MDLBLT,
  FUNCTION_NAME_MDLBLN,
  FUNCTION_NAME_MDLACH,
  FUNCTION_NAME_MDISCI,
  FUNCTION_NAME_MDIPAR,
  FUNCTION_NAME_MDIPAN,
  FUNCTION_NAME_MDIPAI,
  FUNCTION_NAME_MDIOSA,
  FUNCTION_NAME_MDIOLA,
  FUNCTION_NAME_MDILNB,
  FUNCTION_NAME_MDIFNB,
  FUNCTION_NAME_MDIATY,
  FUNCTION_NAME_MDGLTY,
  FUNCTION_NAME_MDGETR,
  FUNCTION_NAME_MDGETL,
  FUNCTION_NAME_MDGETI,
  FUNCTION_NAME_MDGETD,
  FUNCTION_NAME_MDGETC,
  FUNCTION_NAME_MDFNME,
  FUNCTION_NAME_MAPVEC,
  FUNCTION_NAME_MAPTRN,
  FUNCTION_NAME_MAPTRI,
  FUNCTION_NAME_MAPTRA,
  FUNCTION_NAME_MAPSTR,
  FUNCTION_NAME_MAPSTL,
  FUNCTION_NAME_MAPSTI,
  FUNCTION_NAME_MAPSTD,
  FUNCTION_NAME_MAPSTC,
  FUNCTION_NAME_MAPSAV,
  FUNCTION_NAME_MAPRST,
  FUNCTION_NAME_MAPRS,
  FUNCTION_NAME_MAPPOS,
  FUNCTION_NAME_MAPLOT,
  FUNCTION_NAME_MAPLMB,
  FUNCTION_NAME_MAPLBL,
  FUNCTION_NAME_MAPITD,
  FUNCTION_NAME_MAPIT,
  FUNCTION_NAME_MAPIQM,
  FUNCTION_NAME_MAPIQD,
  FUNCTION_NAME_MAPIQA,
  FUNCTION_NAME_MAPIQ,
  FUNCTION_NAME_MAPINT,
  FUNCTION_NAME_MAPGTR,
  FUNCTION_NAME_MAPGTL,
  FUNCTION_NAME_MAPGTI,
  FUNCTION_NAME_MAPGTD,
  FUNCTION_NAME_MAPGTC,
  FUNCTION_NAME_MAPGRM,
  FUNCTION_NAME_MAPGRD,
  FUNCTION_NAME_MAPFST,
  FUNCTION_NAME_MAPDRW,
  FUNCTION_NAME_MAPBLM,
  FUNCTION_NAME_MAPBLA,
  FUNCTION_NAME_MAPACI,
  FUNCTION_NAME_LINED,
  FUNCTION_NAME_LINE3,
  FUNCTION_NAME_LINE,
  FUNCTION_NAME_LBSETR,
  FUNCTION_NAME_LBSETI,
  FUNCTION_NAME_LBGETR,
  FUNCTION_NAME_LBGETI,
  FUNCTION_NAME_LASTD,
  FUNCTION_NAME_KUPY,
  FUNCTION_NAME_KUPX,
  FUNCTION_NAME_KUMY,
  FUNCTION_NAME_KUMX,
  FUNCTION_NAME_KPMY,
  FUNCTION_NAME_KPMX,
  FUNCTION_NAME_KMPY,
  FUNCTION_NAME_KMPX,
  FUNCTION_NAME_KFPY,
  FUNCTION_NAME_KFPX,
  FUNCTION_NAME_KFMY,
  FUNCTION_NAME_KFMX,
  FUNCTION_NAME_ISTR32,
  FUNCTION_NAME_ISSETR,
  FUNCTION_NAME_ISSETI,
  FUNCTION_NAME_ISPLTF,
  FUNCTION_NAME_ISOSCR,
  FUNCTION_NAME_ISGETR,
  FUNCTION_NAME_ISGETI,
  FUNCTION_NAME_ICLOEM,
  FUNCTION_NAME_HSVRGB,
  FUNCTION_NAME_HSTOPR,
  FUNCTION_NAME_HSTOPL,
  FUNCTION_NAME_HSTOPC,
  FUNCTION_NAME_HLSRGB,
  FUNCTION_NAME_GUWK,
  FUNCTION_NAME_GTX,
  FUNCTION_NAME_GSWN,
  FUNCTION_NAME_GSVP,
  FUNCTION_NAME_GSTXP,
  FUNCTION_NAME_GSTXFP,
  FUNCTION_NAME_GSTXCI,
  FUNCTION_NAME_GSTXAL,
  FUNCTION_NAME_GSPMCI,
  FUNCTION_NAME_GSPLCI,
  FUNCTION_NAME_GSMKSC,
  FUNCTION_NAME_GSMK,
  FUNCTION_NAME_GSLWSC,
  FUNCTION_NAME_GSLN,
  FUNCTION_NAME_GSFASI,
  FUNCTION_NAME_GSFAIS,
  FUNCTION_NAME_GSFACI,
  FUNCTION_NAME_GSELNT,
  FUNCTION_NAME_GSCLIP,
  FUNCTION_NAME_GSCHXP,
  FUNCTION_NAME_GSCHUP,
  FUNCTION_NAME_GSCHSP,
  FUNCTION_NAME_GSCHH,
  FUNCTION_NAME_GRIDL,
  FUNCTION_NAME_GRID,
  FUNCTION_NAME_GQTXP,
  FUNCTION_NAME_GQTXFP,
  FUNCTION_NAME_GQTXCI,
  FUNCTION_NAME_GQTXAL,
  FUNCTION_NAME_GQPMCI,
  FUNCTION_NAME_GQPLCI,
  FUNCTION_NAME_GQOPSG,
  FUNCTION_NAME_GQOPS,
  FUNCTION_NAME_GQMNTN,
  FUNCTION_NAME_GQMKSC,
  FUNCTION_NAME_GQMK,
  FUNCTION_NAME_GQLWSC,
  FUNCTION_NAME_GQLN,
  FUNCTION_NAME_GQFASI,
  FUNCTION_NAME_GQFAIS,
  FUNCTION_NAME_GQFACI,
  FUNCTION_NAME_GQCNTN,
  FUNCTION_NAME_GQCHXP,
  FUNCTION_NAME_GQCHSP,
  FUNCTION_NAME_GQCHH,
  FUNCTION_NAME_GPM,
  FUNCTION_NAME_GPL,
  FUNCTION_NAME_GOPWK,
  FUNCTION_NAME_GOPKS,
  FUNCTION_NAME_GFLAS3,
  FUNCTION_NAME_GFLAS2,
  FUNCTION_NAME_GFLAS1,
  FUNCTION_NAME_GFA,
  FUNCTION_NAME_GETUSV,
  FUNCTION_NAME_GETSI,
  FUNCTION_NAME_GDSG,
  FUNCTION_NAME_GDAWK,
  FUNCTION_NAME_GCSGWK,
  FUNCTION_NAME_GCRSG,
  FUNCTION_NAME_GCLWK,
  FUNCTION_NAME_GCLSG,
  FUNCTION_NAME_GCLRWK,
  FUNCTION_NAME_GCLKS,
  FUNCTION_NAME_GASETR,
  FUNCTION_NAME_GASETI,
  FUNCTION_NAME_GASETC,
  FUNCTION_NAME_GAGETR,
  FUNCTION_NAME_GAGETI,
  FUNCTION_NAME_GAGETC,
  FUNCTION_NAME_GACWK,
  FUNCTION_NAME_GACOLR,
  FUNCTION_NAME_FTITLE,
  FUNCTION_NAME_FRSTPT,
  FUNCTION_NAME_FRSTD,
  FUNCTION_NAME_FRST3,
  FUNCTION_NAME_FRAME,
  FUNCTION_NAME_EZHFTN,
  FUNCTION_NAME_EZCNTR,
  FUNCTION_NAME_ERROF,
  FUNCTION_NAME_EPRIN,
  FUNCTION_NAME_DPVECT,
  FUNCTION_NAME_DPSMTH,
  FUNCTION_NAME_DPSETR,
  FUNCTION_NAME_DPSETI,
  FUNCTION_NAME_DPSETC,
  FUNCTION_NAME_DPLINE,
  FUNCTION_NAME_DPLAST,
  FUNCTION_NAME_DPGETR,
  FUNCTION_NAME_DPGETI,
  FUNCTION_NAME_DPGETC,
  FUNCTION_NAME_DPFRST,
  FUNCTION_NAME_DPDRAW,
  FUNCTION_NAME_DPCURV,
  FUNCTION_NAME_DISPLA,
  FUNCTION_NAME_DASHDC,
  FUNCTION_NAME_DASHDB,
  FUNCTION_NAME_CURVED,
  FUNCTION_NAME_CURVE,
  FUNCTION_NAME_CUFY,
  FUNCTION_NAME_CUFX,
  FUNCTION_NAME_CPUY,
  FUNCTION_NAME_CPUX,
  FUNCTION_NAME_CPSPS1,
  FUNCTION_NAME_CPSPRS,
  FUNCTION_NAME_CPSETR,
  FUNCTION_NAME_CPSETI,
  FUNCTION_NAME_CPSETC,
  FUNCTION_NAME_CPRSET,
  FUNCTION_NAME_CPPKLB,
  FUNCTION_NAME_CPPKCL,
  FUNCTION_NAME_CPLBDR,
  FUNCTION_NAME_CPLBAM,
  FUNCTION_NAME_CPGETR,
  FUNCTION_NAME_CPGETI,
  FUNCTION_NAME_CPGETC,
  FUNCTION_NAME_CPFY,
  FUNCTION_NAME_CPFX,
  FUNCTION_NAME_CPEZCT,
  FUNCTION_NAME_CPCLDR,
  FUNCTION_NAME_CPCLAM,
  FUNCTION_NAME_CPBACK,
  FUNCTION_NAME_CONOP4,
  FUNCTION_NAME_CONOP1,
  FUNCTION_NAME_CMUY,
  FUNCTION_NAME_CMUX,
  FUNCTION_NAME_CMFY,
  FUNCTION_NAME_CMFX,
  FUNCTION_NAME_CLSGKS,
  FUNCTION_NAME_CFUY,
  FUNCTION_NAME_CFUX,
  FUNCTION_NAME_ARSETR,
  FUNCTION_NAME_ARSETI,
  FUNCTION_NAME_ARPRAM,
  FUNCTION_NAME_ARGETR,
  FUNCTION_NAME_ARGETI,
  FUNCTION_NAME_AGSETR,
  FUNCTION_NAME_AGSETP,
  FUNCTION_NAME_AGSETI,
  FUNCTION_NAME_AGSETF,
  FUNCTION_NAME_AGSETC,
  FUNCTION_NAME_AGSAVE,
  FUNCTION_NAME_AGRSTR,
  FUNCTION_NAME_AGGETR,
  FUNCTION_NAME_AGGETP,
  FUNCTION_NAME_AGGETI,
  FUNCTION_NAME_AGGETF,
  FUNCTION_NAME_AGGETC,
  FUNCTION_NAME_AGDSHN,
  FUNCTION_NAME_AGBNCH,
  FUNCTION_NAME_AGBACK,
  FUNCTION_NAME_NNSETRD,
  FUNCTION_NAME_NNSETR,
  FUNCTION_NAME_NNSETI,
  FUNCTION_NAME_NNSETC,
  FUNCTION_NAME_NNPNTENDD,
  FUNCTION_NAME_NNPNTEND,
  FUNCTION_NAME_NNGETSLOPES,
  FUNCTION_NAME_NNGETSLOPED,
  FUNCTION_NAME_NNGETRD,
  FUNCTION_NAME_NNGETR,
  FUNCTION_NAME_NNGETI,
  FUNCTION_NAME_NNGETC,
  FUNCTION_NAME_NNGETASPECTS,
  FUNCTION_NAME_NNGETASPECTD,
  FUNCTION_NAME_NATGRIDS,
  FUNCTION_NAME_NATGRIDD,
  FUNCTION_NAME_KURVPD,
  FUNCTION_NAME_KURVP2,
  FUNCTION_NAME_KURVD,
  FUNCTION_NAME_KURV2,
  FUNCTION_NAME_DSSETRD,
  FUNCTION_NAME_DSSETR,
  FUNCTION_NAME_DSSETI,
  FUNCTION_NAME_DSSETC,
  FUNCTION_NAME_DSGRID2S,
  FUNCTION_NAME_DSGRID2D,
  FUNCTION_NAME_DSGETRD,
  FUNCTION_NAME_DSGETR,
  FUNCTION_NAME_DSGETI,
  FUNCTION_NAME_DSGETC,
  FUNCTION_NAME_CURVD,
  FUNCTION_NAME_CURV2,
  FUNCTION_NAME_CSSETR,
  FUNCTION_NAME_CSSETI,
  FUNCTION_NAME_CSSETD,
  FUNCTION_NAME_CSS2CD,
  FUNCTION_NAME_CSS2C,
  FUNCTION_NAME_CSGETR,
  FUNCTION_NAME_CSGETI,
  FUNCTION_NAME_CSGETD,
  FUNCTION_NAME_CSC2SD,
  FUNCTION_NAME_CSC2S,
  FUNCTION_NAME_TOTAL_COUNT
} FUNCTION_NAME;

void* ncar_functions[] = {
  (void*)yiqrgb_,
  (void*)wmw2ny_,
  (void*)wmw2nx_,
  (void*)wmsetr_,
  (void*)wmseti_,
  (void*)wmsetc_,
  (void*)wmlabw_,
  (void*)wmlabs_,
  (void*)wmgetr_,
  (void*)wmgeti_,
  (void*)wmgetc_,
  (void*)wmdrft_,
  (void*)wmdflt_,
  (void*)wmbarb_,
  (void*)vvsetr_,
  (void*)vvseti_,
  (void*)vvsetc_,
  (void*)vvrset_,
  (void*)vvinit_,
  (void*)vvgetr_,
  (void*)vvgeti_,
  (void*)vvgetc_,
  (void*)vvectr_,
  (void*)vector_,
  (void*)vectd_,
  (void*)vect3_,
  (void*)trn32s_,
  (void*)trn32i_,
  (void*)ticks_,
  (void*)tick4_,
  (void*)tdsetr_,
  (void*)tdseti_,
  (void*)tdprpi_,
  (void*)tdprpa_,
  (void*)tdplch_,
  (void*)tdpara_,
  (void*)tdlnpa_,
  (void*)tdline_,
  (void*)tdgetr_,
  (void*)tdgeti_,
  (void*)supcon_,
  (void*)stsetr_,
  (void*)stseti_,
  (void*)strset_,
  (void*)stream_,
  (void*)stinit_,
  (void*)stgetr_,
  (void*)stgeti_,
  (void*)slsetr_,
  (void*)slseti_,
  (void*)slrset_,
  (void*)slgetr_,
  (void*)slgeti_,
  (void*)sfwrld_,
  (void*)sfsetr_,
  (void*)sfsetp_,
  (void*)sfseti_,
  (void*)sfsetc_,
  (void*)sfnorm_,
  (void*)sflush_,
  (void*)sfgetr_,
  (void*)sfgetp_,
  (void*)sfgeti_,
  (void*)sfgetc_,
  (void*)setusv_,
  (void*)seter_,
  (void*)rgbyiq_,
  (void*)rgbhsv_,
  (void*)rgbhls_,
  (void*)retsr_,
  (void*)pwrzt_,
  (void*)pwrzs_,
  (void*)pwrzi_,
  (void*)pwritx_,
  (void*)pwrit_,
  (void*)point3_,
  (void*)point_,
  (void*)plotit_,
  (void*)plotif_,
  (void*)plchmq_,
  (void*)plchlq_,
  (void*)plchhq_,
  (void*)periml_,
  (void*)perim_,
  (void*)pcsetr_,
  (void*)pcseti_,
  (void*)pcsetc_,
  (void*)pcmequ_,
  (void*)pcloqu_,
  (void*)pchiqu_,
  (void*)pcgetr_,
  (void*)pcgeti_,
  (void*)pcgetc_,
  (void*)pcdlsc_,
  (void*)opngks_,
  (void*)ngsetr_,
  (void*)ngseti_,
  (void*)ngsetc_,
  (void*)ngpict_,
  (void*)ngmftc_,
  (void*)nggetr_,
  (void*)nggeti_,
  (void*)nggetc_,
  (void*)ngezlogo_,
  (void*)ngckop_,
  (void*)mputis_,
  (void*)mputin_,
  (void*)mputid_,
  (void*)mputfs_,
  (void*)mputfd_,
  (void*)mpsetr_,
  (void*)mpsetl_,
  (void*)mpseti_,
  (void*)mpsetd_,
  (void*)mpsetc_,
  (void*)mprset_,
  (void*)mplnri_,
  (void*)mplndr_,
  (void*)mplnam_,
  (void*)mpisci_,
  (void*)mpipar_,
  (void*)mpipan_,
  (void*)mpipai_,
  (void*)mpiosa_,
  (void*)mpiola_,
  (void*)mpilnb_,
  (void*)mpifnb_,
  (void*)mpiaty_,
  (void*)mpglty_,
  (void*)mpgetr_,
  (void*)mpgetl_,
  (void*)mpgeti_,
  (void*)mpgetd_,
  (void*)mpgetc_,
  (void*)mpfnme_,
  (void*)mdutis_,
  (void*)mdutin_,
  (void*)mdutid_,
  (void*)mdutfs_,
  (void*)mdutfd_,
  (void*)mdsetr_,
  (void*)mdsetl_,
  (void*)mdseti_,
  (void*)mdsetd_,
  (void*)mdsetc_,
  (void*)mdrset_,
  (void*)mdrgsc_,
  (void*)mdrggc_,
  (void*)mdrgdl_,
  (void*)mdpvec_,
  (void*)mdptrn_,
  (void*)mdptri_,
  (void*)mdptra_,
  (void*)mdpsav_,
  (void*)mdprst_,
  (void*)mdprs_,
  (void*)mdplot_,
  (void*)mdplmb_,
  (void*)mdplbl_,
  (void*)mdpitd_,
  (void*)mdpit_,
  (void*)mdpiqm_,
  (void*)mdpiqd_,
  (void*)mdpiqa_,
  (void*)mdpiq_,
  (void*)mdpint_,
  (void*)mdpgrm_,
  (void*)mdpgrd_,
  (void*)mdpfst_,
  (void*)mdpdrw_,
  (void*)mdpblm_,
  (void*)mdpbla_,
  (void*)mdpaci_,
  (void*)mdloch_,
  (void*)mdlnri_,
  (void*)mdlndr_,
  (void*)mdlnam_,
  (void*)mdlblt_,
  (void*)mdlbln_,
  (void*)mdlach_,
  (void*)mdisci_,
  (void*)mdipar_,
  (void*)mdipan_,
  (void*)mdipai_,
  (void*)mdiosa_,
  (void*)mdiola_,
  (void*)mdilnb_,
  (void*)mdifnb_,
  (void*)mdiaty_,
  (void*)mdglty_,
  (void*)mdgetr_,
  (void*)mdgetl_,
  (void*)mdgeti_,
  (void*)mdgetd_,
  (void*)mdgetc_,
  (void*)mdfnme_,
  (void*)mapvec_,
  (void*)maptrn_,
  (void*)maptri_,
  (void*)maptra_,
  (void*)mapstr_,
  (void*)mapstl_,
  (void*)mapsti_,
  (void*)mapstd_,
  (void*)mapstc_,
  (void*)mapsav_,
  (void*)maprst_,
  (void*)maprs_,
  (void*)mappos_,
  (void*)maplot_,
  (void*)maplmb_,
  (void*)maplbl_,
  (void*)mapitd_,
  (void*)mapit_,
  (void*)mapiqm_,
  (void*)mapiqd_,
  (void*)mapiqa_,
  (void*)mapiq_,
  (void*)mapint_,
  (void*)mapgtr_,
  (void*)mapgtl_,
  (void*)mapgti_,
  (void*)mapgtd_,
  (void*)mapgtc_,
  (void*)mapgrm_,
  (void*)mapgrd_,
  (void*)mapfst_,
  (void*)mapdrw_,
  (void*)mapblm_,
  (void*)mapbla_,
  (void*)mapaci_,
  (void*)lined_,
  (void*)line3_,
  (void*)line_,
  (void*)lbsetr_,
  (void*)lbseti_,
  (void*)lbgetr_,
  (void*)lbgeti_,
  (void*)lastd_,
  (void*)kupy_,
  (void*)kupx_,
  (void*)kumy_,
  (void*)kumx_,
  (void*)kpmy_,
  (void*)kpmx_,
  (void*)kmpy_,
  (void*)kmpx_,
  (void*)kfpy_,
  (void*)kfpx_,
  (void*)kfmy_,
  (void*)kfmx_,
  (void*)istr32_,
  (void*)issetr_,
  (void*)isseti_,
  (void*)ispltf_,
  (void*)isoscr_,
  (void*)isgetr_,
  (void*)isgeti_,
  (void*)icloem_,
  (void*)hsvrgb_,
  (void*)hstopr_,
  (void*)hstopl_,
  (void*)hstopc_,
  (void*)hlsrgb_,
  (void*)guwk_,
  (void*)gtx_,
  (void*)gswn_,
  (void*)gsvp_,
  (void*)gstxp_,
  (void*)gstxfp_,
  (void*)gstxci_,
  (void*)gstxal_,
  (void*)gspmci_,
  (void*)gsplci_,
  (void*)gsmksc_,
  (void*)gsmk_,
  (void*)gslwsc_,
  (void*)gsln_,
  (void*)gsfasi_,
  (void*)gsfais_,
  (void*)gsfaci_,
  (void*)gselnt_,
  (void*)gsclip_,
  (void*)gschxp_,
  (void*)gschup_,
  (void*)gschsp_,
  (void*)gschh_,
  (void*)gridl_,
  (void*)grid_,
  (void*)gqtxp_,
  (void*)gqtxfp_,
  (void*)gqtxci_,
  (void*)gqtxal_,
  (void*)gqpmci_,
  (void*)gqplci_,
  (void*)gqopsg_,
  (void*)gqops_,
  (void*)gqmntn_,
  (void*)gqmksc_,
  (void*)gqmk_,
  (void*)gqlwsc_,
  (void*)gqln_,
  (void*)gqfasi_,
  (void*)gqfais_,
  (void*)gqfaci_,
  (void*)gqcntn_,
  (void*)gqchxp_,
  (void*)gqchsp_,
  (void*)gqchh_,
  (void*)gpm_,
  (void*)gpl_,
  (void*)gopwk_,
  (void*)gopks_,
  (void*)gflas3_,
  (void*)gflas2_,
  (void*)gflas1_,
  (void*)gfa_,
  (void*)getusv_,
  (void*)getsi_,
  (void*)gdsg_,
  (void*)gdawk_,
  (void*)gcsgwk_,
  (void*)gcrsg_,
  (void*)gclwk_,
  (void*)gclsg_,
  (void*)gclrwk_,
  (void*)gclks_,
  (void*)gasetr_,
  (void*)gaseti_,
  (void*)gasetc_,
  (void*)gagetr_,
  (void*)gageti_,
  (void*)gagetc_,
  (void*)gacwk_,
  (void*)gacolr_,
  (void*)ftitle_,
  (void*)frstpt_,
  (void*)frstd_,
  (void*)frst3_,
  (void*)frame_,
  (void*)ezhftn_,
  (void*)ezcntr_,
  (void*)errof_,
  (void*)eprin_,
  (void*)dpvect_,
  (void*)dpsmth_,
  (void*)dpsetr_,
  (void*)dpseti_,
  (void*)dpsetc_,
  (void*)dpline_,
  (void*)dplast_,
  (void*)dpgetr_,
  (void*)dpgeti_,
  (void*)dpgetc_,
  (void*)dpfrst_,
  (void*)dpdraw_,
  (void*)dpcurv_,
  (void*)displa_,
  (void*)dashdc_,
  (void*)dashdb_,
  (void*)curved_,
  (void*)curve_,
  (void*)cufy_,
  (void*)cufx_,
  (void*)cpuy_,
  (void*)cpux_,
  (void*)cpsps1_,
  (void*)cpsprs_,
  (void*)cpsetr_,
  (void*)cpseti_,
  (void*)cpsetc_,
  (void*)cprset_,
  (void*)cppklb_,
  (void*)cppkcl_,
  (void*)cplbdr_,
  (void*)cplbam_,
  (void*)cpgetr_,
  (void*)cpgeti_,
  (void*)cpgetc_,
  (void*)cpfy_,
  (void*)cpfx_,
  (void*)cpezct_,
  (void*)cpcldr_,
  (void*)cpclam_,
  (void*)cpback_,
  (void*)conop4_,
  (void*)conop1_,
  (void*)cmuy_,
  (void*)cmux_,
  (void*)cmfy_,
  (void*)cmfx_,
  (void*)clsgks_,
  (void*)cfuy_,
  (void*)cfux_,
  (void*)arsetr_,
  (void*)arseti_,
  (void*)arpram_,
  (void*)argetr_,
  (void*)argeti_,
  (void*)agsetr_,
  (void*)agsetp_,
  (void*)agseti_,
  (void*)agsetf_,
  (void*)agsetc_,
  (void*)agsave_,
  (void*)agrstr_,
  (void*)aggetr_,
  (void*)aggetp_,
  (void*)aggeti_,
  (void*)aggetf_,
  (void*)aggetc_,
  (void*)agdshn_,
  (void*)agbnch_,
  (void*)agback_,
  (void*)nnsetrd_,
  (void*)nnsetr_,
  (void*)nnseti_,
  (void*)nnsetc_,
  (void*)nnpntendd_,
  (void*)nnpntend_,
  (void*)nngetslopes_,
  (void*)nngetsloped_,
  (void*)nngetrd_,
  (void*)nngetr_,
  (void*)nngeti_,
  (void*)nngetc_,
  (void*)nngetaspects_,
  (void*)nngetaspectd_,
  (void*)natgrids_,
  (void*)natgridd_,
  (void*)kurvpd_,
  (void*)kurvp2_,
  (void*)kurvd_,
  (void*)kurv2_,
  (void*)dssetrd_,
  (void*)dssetr_,
  (void*)dsseti_,
  (void*)dssetc_,
  (void*)dsgrid2s_,
  (void*)dsgrid2d_,
  (void*)dsgetrd_,
  (void*)dsgetr_,
  (void*)dsgeti_,
  (void*)dsgetc_,
  (void*)curvd_,
  (void*)curv2_,
  (void*)cssetr_,
  (void*)csseti_,
  (void*)cssetd_,
  (void*)css2cd_,
  (void*)css2c_,
  (void*)csgetr_,
  (void*)csgeti_,
  (void*)csgetd_,
  (void*)csc2sd_,
  (void*)csc2s_,
  (void*)0
};

#endif
